---
title: <span class="badge builder"></span> LibraryElementDTOMetaUser
---
# <span class="badge builder"></span> LibraryElementDTOMetaUser

## Constructor

```python
LibraryElementDTOMetaUser()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> librarypanel.LibraryElementDTOMetaUser
```

### <span class="badge object-method"></span> avatar_url

```python
def avatar_url(avatar_url: str) -> typing.Self
```

### <span class="badge object-method"></span> id_val

```python
def id_val(id_val: int) -> typing.Self
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [LibraryElementDTOMetaUser](./object-LibraryElementDTOMetaUser.md)
